@@ -34,13 +34,18 @@ flatpak install -y flathub com.visualstudio.code
 cp ./CODE.sh /usr/bin/CODE
 chmod a+x /usr/bin/CODE
 
+
 # flatpak install -y flathub org.onionshare.OnionShare
 # cp ./onionshare.sh /usr/bin/onionshare
 # chmod a+x /usr/bin/onionshare
 
+# my personal printer driver... well not very generic (TBD: change that)
+rpm -i hll2350dwpdrv-4.0.0-1.i386.rpm
+
 # to replace dropbox 
 zypper in -y tor torbrowser-launcher # python3-onionshare 
 
+
 zypper in -y MozillaThunderbird MozillaThunderbird-translations-common
 # If the main directory is not preserved `~/.thunderbird` must be reconstructed.
 # Also ensure that there is a link to thunderbird on the desktop
@@ -64,6 +69,7 @@ zypper in -y git git-doc bash-git-prompt git-filter-repo git-lfs `# git` \
   dolphin-plugins gh gitg git-web git-cola glab git-mr `# GUI backends for git/mercurial` \
   kdiff3 kdiff3-lang tkdiff diffmk diff-pdf `# diffing tools` # meld mgdiff tdiff tkdiff
 
+
 #zypper in -y kdiff3 kdiff3-lang diffmk diff-pdf # meld mgdiff tdiff tkdiff
 
 
@@ -79,11 +85,12 @@ zypper in -y gcc gcc-c++ gcc-fortran gcc-ada gcc-go cross-arm-gcc13 \
   go-doc go `# go` \
   rustup `# rust with package manager cargo` \
   scala `# scala; maybe not enough` \
-  mono-core js `# mono used for tikz editor only, js broadly used ` \
+  mono-core `# mono used for tikz editor only ` \
   squeak-vm `# squeak is a dialect of smalltalk and the package provides a development environment `
 
 #rustup default stable # not as root 
 #rustup update disabled for suse, anyway, update with zypper instead 
+
 # rustup self uninstall 
 
 zypper in -y emacs `#emacs-auctex, maybe emacs no longer needed, maybe aspell for emacs only` \
@@ -102,12 +109,14 @@ zypper in -y \
   texlive-hanging     texlive-stackengine texlive-tocloft texlive-etoc `# for doxygen` \
   texlive-draftwatermark texlive-draftwatermark-doc `# for watermarks like confidential or DRAFT` \
   texlive-jupynotex-doc `# for jupyter notebook` \
-  texlive-latex2man   texlive-latex2nemeth latex2rtf `# converter` \
+
+  texlive-latex2man   texlive-latex2nemeth `# converter` \
   texlive-pdfprivacy  texlive-pdfprivacy-doc `# for pdf` \
   texlive-hyperref    texlive-hyperxmp texlive-hyperxmp-doc `# hyperref and related` \
   texlive-dratex      texlive-dratex-doc `# only used to compile tex2ht` \
   texlive-cprotect    texlive-cprotect-doc `# verbatim in macro` \
   texlive-newverbs    texlive-newverbs-doc `# verbatim as macro` \
+  texlive-collection-basic `# for latex2rtf wrong dependency TBD: check whether necessary` \
   texlive-markdown    texlive-markdown-doc `# markdown into latex` \
   texlive-accessibility texlive-accessibility-doc `# accessibility into latex` \
   texlive-anyfontsize texlive-anyfontsize-doc `# allow any font size` \
@@ -116,17 +125,82 @@ zypper in -y \
   texlive-tikz-optics  texlive-tikz-optics-doc  `# grapical editing for tikz` \
   texlive-adrconv      texlive-adrconv-doc   `# address database as bib file` \
   texlive-pdfpagediff texlive-pdfpagediff-doc `# for pdf` \
+  texlive-showlabels texlive-showlabels-doc `# to make labels visible` \
+  texlive-stix `# additional math like widetilde ` \
+  texlive-mathabx `# additional math fonts ` \
+  texlive-pythontex texlive-pythontex-bin `# pythontex and depythontex (unfortunately outdated; see below) ` \
   exif exiftool qpdf pdftk `# show exif meta data, exiftool is better ` \
     `# Photini, exiv2 and gexif along the same lines as exif` \
   unoconv pandoc texinfo libreoffice `# converter; texinfo implies texihtml and texiroff` \
-  xfig gnuplot inkscape `# converter` \
+   xfig gnuplot inkscape `# converter` \
   libwebp-tools `# converter from webp to png, not yet used` \
   docbook2x discount `# the latter providing command 'markdown'` \
   rubber `# make utils texlive-arara? latexmake not present` \
   epstool `# eps files in latex also for octave` \
+  python313-pygments `# pygments e.g. for pythontex` \
   ktikz `# tikz only viewer not editor and thus no replacement for TikzEdt and also mono` \
   dia `# if exports tikz may be a replacement for TikzEdt and also mono`
 
+zypper in -y latex2rtf `# converter`
+
+# patch package commuative-diagrams
+# TBD: wget -nc avoids downloading if it exists already
+wget -nc -O ./commutative-diagrams.tds.zip https://mirrors.ctan.org/install/graphics/pgf/contrib/commutative-diagrams.tds.zip
+cp ./commutative-diagrams.tds.zip /usr/share/texmf/
+pushd /usr/share/texmf/
+unzip -o commutative-diagrams.tds.zip
+rm commutative-diagrams.tds.zip
+popd
+
+# Bugfix in fork, pull requested but so far no merge 
+wget -O /usr/share/texmf/scripts/pythontex/pythontex3.py   https://www.simuline.eu/Pythontex/pythontex3.py
+wget -O /usr/share/texmf/scripts/pythontex/depythontex3.py https://www.simuline.eu/Pythontex/depythontex3.py
+
+
+# TBD: It is not ok just to patch into an existing and clean texlive installation. 
+# To improve this, one shall install texlive in the standardized way, not via suse. 
+mkdir -p /usr/share/texmf/bibtex/bst/abstract/
+wget -nc -O /usr/share/texmf/bibtex/bst/abstract/abstract.bst http://tug.ctan.org/tex-archive/biblio/bibtex/utils/bibtools/abstract.bst
+
+# # TBD: It is not ok just to patch into an existing and clean texlive installation. 
+# # To improve this, one shall install texlive in the standardized way, not via suse. 
+# tikzVersion=tikzuml-v1.0-2016-03-29
+# #tikzuml-v1.0-2016-03-29
+# wget -nc -O $tikzVersion.tbz https://perso.ensta-paris.fr/~kielbasi/tikzuml/var/files/src/$tikzVersion.tbz
+# chmod a+w $tikzVersion.tbz
+# if ! [[ -e $tikzVersion ]]; then
+#   tar -xvf $tikzVersion.tbz
+#   chmod -R a+w $tikzVersion
+#   pushd $tikzVersion
+#   mkdir -p /usr/share/texmf/tex/latex/tikz-uml/
+#   cp tikz-uml.sty /usr/share/texmf/tex/latex/tikz-uml/
+#   mkdir -p /usr/share/texmf/doc/latex/tikz-uml
+#   cp -r doc/* /usr/share/texmf/doc/latex/tikz-uml
+#   popd
+# fi
+
+
+# TBD: this shall be done inside the project. 
+# this is a patch, which shall not be necessary in the long run. 
+# It may even cause a problem if the package is updated. 
+# The patch is from a dark channel 
+# https://tex.stackexchange.com/questions/682383/htlatex-problem-with-caption-in-longtable/682399?noredirect=1#comment1693273_682399
+cp ./tex4ht/longtable.4ht /usr/share/texmf/tex/generic/tex4ht/longtable.4ht 
+
+texconfig rehash # part of texlive 
+
+
+#zypper in -y jabref # this did not work: older version, problem with javafx
+# jabrefVersion=5.9-1.x86_64%6.0-1
+jabrefVersion=6.0-1
+# old url
+# wget -nc -O ./jabref-$jabrefVersion.rpm https://www.fosshub.com/JabRef.html?dwl=jabref-$jabrefVersion.rpm
+# new url 
+wget -nc -O ./jabref-$jabrefVersion.rpm https://builds.jabref.org/main/jabref-$jabrefVersion.x86_64.rpm
+rpm -i ./jabref-$jabrefVersion.rpm
+pushd /usr/local/bin/
+ln -sf /opt/jabref/bin/JabRef JabRef
+popd
 
 # TBD: It is not ok just to patch into an existing and clean texlive installation. 
 # To improve this, one shall install texlive in the standardized way, not via suse. 
@@ -178,22 +252,29 @@ zypper in -y java-11-openjdk-src java-11-openjdk java-11-openjdk-devel `# java11
   maven `# basic build tool` \
   jenkins dejavu-fonts fontconfig 
 
+update-alternatives --set java $(update-alternatives --list java | grep jre-17)
 
 # some utilities 
 zypper in -y kruler cheese `# webcam` \
+  indent `# indent` \
   system-user-uucp uucp cutecom moreutils zip bzip2-doc gparted \
   dhex ktorrent stress-ng \
+  memtest86+ \
   sensors acpi hddtemp hardinfo qt6-sensors `# temperature monitoring` \
-  lshw `# hardware info` \
+  lshw sysstat `# hardware info` \
   xsane spectacle gimp k3b `# scanning, screenshot, image processing and burning` \
   vlc `# films` \
-  whatsapp-purple `# displaylink not found` \
+  opi `# opensuse package installer: sth to download e.g. codecs` \
+  `#whatsapp-purple # displaylink not found` \
   `# the proper app: not working whatsie.x86_64 could be whatsapp-for-linux` \
   `# skype whatsapp is with snap currently, maybe skypeforlinux or flatpak` \
   kdeconnect-kde `# of course also on mobile kdeconnect must be installed. ` \
   dropbox-cli `# a drop box comand line client ` \
   luvcview `# driver for most webcams`
 
+  opi -n codecs
+  # TBD: use in general context: more vendors 
+  # like chrome, codecs, dotnet, freeoffice, skype, teams-for-linux teamviewer zoom
 
 # there are much more packages on octave-forge worth being investigated
 # octave-devel is to be able to add packages
@@ -215,9 +296,15 @@ zypper in -y octave octave-devel \
   mpfr-devel `# for installing certain packages`
 
 
+# python 
+
+zypper in -y python313-pipx python313-paramiko
+#pipx install diff-pdf-visually
+
+
 # what is needed for docker  
 # decativated docker-kubic docker-kubic-bash-completion \
-zypper in -y python3-docker yast2-docker
+zypper in -y python3-docker #yast2-docker
 
 # this is a hack only
 if rpm -q firewalld  >/dev/null ;
@@ -233,9 +320,11 @@ systemctl enable docker
 zypper in -y podman podmansh #podman-docker
 
 
+
 zypper in -y inotify-tools
 
 
+
 zypper in -y distrobox distrobox-bash-completion
 # This was a trial on tikzit 
 # more general, distrobox is very useful to invite other linux distributions 
@@ -246,12 +335,12 @@ zypper in -y distrobox distrobox-bash-completion
 zypper in -y yum rpm-build `#to build rpm packages`
 
 # addrepo.sh adds special repo for that 
-zypper dist-upgrade -y --from packman --allow-vendor-change
+
+#zypper dist-upgrade -y --from packman --allow-vendor-change
 # TBD: following not found
 # libavcodec58 libavdevice58 libavfilter7 libavformat58 libavutil56 
-zypper in -y --from packman ffmpeg \
-  gstreamer-plugins-bad gstreamer-plugins-libav gstreamer-plugins-ugly \
-  libavresample4 #vlc-codecs packman ffmpeg 
+zypper in -y gstreamer-plugins-good gstreamer-plugins-libav libavresample4 #vlc-codecs packman ffmpeg 
+
 
 zypper in -y virtualbox
 
@@ -259,7 +348,9 @@ zypper in -y gnome-keyring
 
 # Web development 
 zypper in -y apache2-devel apache2-manual apache2-mod_php8 apache2-mod_perl
-zypper in -y nodejs20 nodejs20-devel nodejs20-docs
+#zypper in -y nodejs20 nodejs20-devel nodejs20-docs
+zypper in -y nodejs-default nodejs-devel-default nodejs22-docs
+zypper in -y nodejs-electron nodejs-electron-devel nodejs-electron-doc
 zypper in -y tomcat10
 # to use tomcat add 
 #export CATALINA_HOME=/usr/share/tomcat/
@@ -271,17 +362,19 @@ zypper in -y tomcat10
 
 # deinstall python 2.7 and dependencies
 # this is a hack only
-if rpm -q python  >/dev/null ;
-then
-  zypper rm -y gimp-plugins-python python-gobject2 python-gtk  python2-pycairo 
-  zypper rm -y python `# python-xml python-base` 
-  zypper rm -y libpython2_7-1_0
-fi
+
+#if rpm -q python  >/dev/null ;
+#then
+#  zypper rm -y gimp-plugins-python python-gobject2 python-gtk  python2-pycairo 
+#  zypper rm -y python `# python-xml python-base` 
+#  zypper rm -y libpython2_7-1_0
+#fi
 
 # Perl modules,.. mostly latex plugin, may be incomplete 
 zypper in -y perl-Capture-Tiny perl-DateTime-Format-ISO8601
 
 
+
 #zypper in -y teams
 #if rpm -q teams  >/dev/null ;
 #then
@@ -289,11 +382,19 @@ zypper in -y perl-Capture-Tiny perl-DateTime-Format-ISO8601
 #fi
 #
 # already in zypper 
+
+# TBD: this works only on a second run, when snap demon is working 
+# Thus first run of this script yields an error here. 
+# Then one has to restart the computer and run this script once again. 
+# This is not according to standard. 
+# Solution: run only if  /run/snapd.socket exists. 
+# else display a warning: restart computer and run this script again. 
 snap install whatsdesk 
 snap install whatsapp-for-linux #teams-for-linux
 snap install spark --edge
-
 snap install onionshare
+#snap install jabref
+
 
 
 # TBD: eliminate hard coded path 
